﻿using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.Collections;
using Infragistics.UltraChart.Resources;

namespace ExampleChart
{
    public partial class frmUltraChart : Form
    {
        Random rand = new Random((int)DateTime.Now.Ticks);
        DataTable values, symbols;

        public frmUltraChart()
        {
            InitializeComponent();
            this.ultraChart1.Data.DataSource = GetDemoData();
        }

        private DataTable GetDemoData()
        {
            values = new DataTable();
            symbols = new DataTable();

            values.Columns.Add("c1", typeof(double));
            values.Columns.Add("c2", typeof(double));
            values.Columns.Add("c3", typeof(double));
            values.Columns.Add("c4", typeof(double));
            values.Columns.Add("c5", typeof(double));
            values.Columns.Add("c6", typeof(double));
            values.Columns.Add("c7", typeof(double));

            symbols.Columns.Add("s1", typeof(string));
            symbols.Columns.Add("s2", typeof(string));
            symbols.Columns.Add("s3", typeof(string));
            symbols.Columns.Add("s4", typeof(string));
            symbols.Columns.Add("s5", typeof(string));
            symbols.Columns.Add("s6", typeof(string));
            symbols.Columns.Add("s7", typeof(string));

            DataRow dr;
            for (int i = 0; i < 10; i++)
            {
                dr = values.NewRow();
                dr[0] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                dr[1] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                dr[2] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                dr[3] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                dr[4] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                dr[5] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                dr[6] = rand.NextDouble() * (i % 2 == 0 ? 10 : -10);
                values.Rows.Add(dr);

                dr = symbols.NewRow();
                for (int j = 0; j < symbols.Columns.Count; j++)
                {
                    dr[j] = this.GenerateSymbol();
                }
                symbols.Rows.Add(dr);
            }

            return values;
        }

        private string GenerateSymbol()
        {
            return string.Empty + (Char)rand.Next(65, 91) + (Char)rand.Next(65, 91) + (Char)rand.Next(65, 91);
        }

        private void frmUltraChart_Load(object sender, EventArgs e)
        {
            LabelRenderer labelRenderer = new LabelRenderer();
            labelRenderer.Values = values;
            labelRenderer.Symbols = symbols;

            this.ultraChart1.LabelHash = new Hashtable();
            this.ultraChart1.LabelHash.Add("CUSTOM", labelRenderer);
            this.ultraChart1.HeatMapChart.ChartText[0].ItemFormatString = "<CUSTOM>";

            this.ultraChart1.ColorModel.ColorBegin = Color.Red;
            this.ultraChart1.ColorModel.Scaling = Infragistics.UltraChart.Shared.Styles.ColorScaling.Increasing;
            this.ultraChart1.ColorModel.ColorEnd = Color.Green;
            this.ultraChart1.ColorModel.ModelStyle = Infragistics.UltraChart.Shared.Styles.ColorModels.LinearRange;
        }
    }

    public class LabelRenderer : IRenderLabel
    {
        public DataTable Values { get; set; }
        public DataTable Symbols { get; set; }

        public string ToString(Hashtable table)
        {
            int row = (int)table["DATA_ROW"];
            int col = (int)table["DATA_COLUMN"];

            string itemLabel = (string)this.Symbols.Rows[row][col];
            double dataValue = (double)this.Values.Rows[row][col];

            return itemLabel + "\n\n    " + dataValue.ToString("n");
        }
    }
}
